/*
 * Copyright (c) 2000 World Wide Web Consortium,
 * (Massachusetts Institute of Technology, Institut National de
 * Recherche en Informatique et en Automatique, Keio University). All
 * Rights Reserved. This program is distributed under the W3C's Software
 * Intellectual Property License. This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
 * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.
 * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
 */

package org.w3c.dom.views;

import org.w3c.dom.Node;

/**
 * The <code>MatchContent</code> identifies <code>Segment</code>s where a 
 * content property matches a specific value.
 * <p>See also the <a href='http://www.w3.org/TR/2000/WD-DOM-Level-3-Views-20001115'>Document Object Model (DOM) Level 3 Views and Formatting
Specification</a>.
 * @since DOM level 3
 */
public interface MatchContent extends Match {
    /**
     * The name of an content property of each <code>Segment</code> to be 
     * compared against, which is specified during construction.
     */
    public String getName();

    /**
     * The Node value to be compared against, which is specified during 
     * construction.
     */
    public Node getNode();

    /**
     * The offset value to be compared against, which is specified during 
     * construction.
     */
    public int getOffset();

}
